smartcard.CardConnectionDecorator.CardConnectionDecorator

# ``smartcard`.`CardConnectionDecorator`.`CardConnectionDecorator``

class documentation

`class CardConnectionDecorator(CardConnection):`

Known subclasses: `smartcard.ExclusiveConnectCardConnection.ExclusiveConnectCardConnection`, `smartcard.ExclusiveTransmitCardConnection.ExclusiveTransmitCardConnection`, `smartcard.pyro.server.RemoteCardConnection.RemoteCardConnection`

View In Hierarchy

Card connection decorator class.

Method | `__init__` | Construct a new card connection decorator.
Method | `addObserver` | call inner component addObserver
Method | `addSWExceptionToFilter` | call inner component addSWExceptionToFilter
Method | `connect` | call inner component connect
Method | `control` | call inner component control
Method | `deleteObserver` | call inner component deleteObserver
Method | `disconnect` | call inner component disconnect
Method | `getATR` | call inner component getATR
Method | `getAttrib` | call inner component getAttrib
Method | `getProtocol` | call inner component getProtocol
Method | `getReader` | call inner component getReader
Method | `reconnect` | call inner component reconnect
Method | `setErrorCheckingChain` | call inner component setErrorCheckingChain
Method | `setProtocol` | call inner component setProtocol
Method | `transmit` | call inner component transmit
Instance Variable | `component` | Undocumented

Inherited from `CardConnection`:

Method | `__del__` | Connect to card.
Method | `__enter__` | Enter the runtime context.
Method | `__exit__` | Exit the runtime context trying to disconnect.
Method | `doControl` | Performs the command control.
Method | `doGetAttrib` | Performs the command get attrib.
Method | `doTransmit` | Performs the command APDU transmission.
Class Variable | `RAW_protocol` | Undocumented
Class Variable | `T0_protocol` | Undocumented
Class Variable | `T15_protocol` | Undocumented
Class Variable | `T1_protocol` | Undocumented
Instance Variable | `defaultprotocol` | Undocumented
Instance Variable | `errorcheckingchain` | Undocumented
Instance Variable | `reader` | Undocumented

Inherited from `Observable` (via `CardConnection`):

Method | `clearChanged` | Undocumented
Method | `countObservers` | Undocumented
Method | `deleteObservers` | Undocumented
Method | `hasChanged` | Undocumented
Method | `notifyObservers` | If 'changed' indicates that this object has changed, notify all its observers, then call clearChanged(). Each observer has its update() called with two arguments: this observable object and the generic 'arg'.
Method | `setChanged` | Undocumented
Instance Variable | `changed` | Undocumented
Instance Variable | `obs` | Undocumented

Inherited from `Synchronization` (via `CardConnection`, `Observable`):

Instance Variable | `mutex` | Undocumented

def __init__(self, cardConnectionComponent):
overrides `smartcard.CardConnection.CardConnection.__init__`
overridden in `smartcard.ExclusiveConnectCardConnection.ExclusiveConnectCardConnection`, `smartcard.ExclusiveTransmitCardConnection.ExclusiveTransmitCardConnection`, `smartcard.pyro.server.RemoteCardConnection.RemoteCardConnection`

Construct a new card connection decorator.

CardConnectionComponent: CardConnection component to decorate

def addObserver(self, observer):
overrides `smartcard.CardConnection.CardConnection.addObserver`

call inner component addObserver

def addSWExceptionToFilter(self, exClass):
overrides `smartcard.CardConnection.CardConnection.addSWExceptionToFilter`

call inner component addSWExceptionToFilter

def connect(self, protocol=None, mode=None, disposition=None):
overrides `smartcard.CardConnection.CardConnection.connect`
overridden in `smartcard.ExclusiveConnectCardConnection.ExclusiveConnectCardConnection`

call inner component connect

def control(self, controlCode, bytes=[]):
overrides `smartcard.CardConnection.CardConnection.control`

call inner component control

def deleteObserver(self, observer):
overrides `smartcard.CardConnection.CardConnection.deleteObserver`

call inner component deleteObserver

def disconnect(self):
overrides `smartcard.CardConnection.CardConnection.disconnect`

call inner component disconnect

def getATR(self):
overrides `smartcard.CardConnection.CardConnection.getATR`

call inner component getATR

def getAttrib(self, attribId):
overrides `smartcard.CardConnection.CardConnection.getAttrib`

call inner component getAttrib

def getProtocol(self):
overrides `smartcard.CardConnection.CardConnection.getProtocol`

call inner component getProtocol

def getReader(self):
overrides `smartcard.CardConnection.CardConnection.getReader`

call inner component getReader

def reconnect(self, protocol=None, mode=None, disposition=None):
overrides `smartcard.CardConnection.CardConnection.reconnect`

call inner component reconnect

def setErrorCheckingChain(self, errorcheckingchain):
overrides `smartcard.CardConnection.CardConnection.setErrorCheckingChain`

call inner component setErrorCheckingChain

def setProtocol(self, protocol):
overrides `smartcard.CardConnection.CardConnection.setProtocol`

call inner component setProtocol

def transmit(self, bytes, protocol=None):
overrides `smartcard.CardConnection.CardConnection.transmit`
overridden in `smartcard.ExclusiveTransmitCardConnection.ExclusiveTransmitCardConnection`

call inner component transmit

component =

Undocumented